import ippidb
from django.shortcuts import render
from django.http import HttpResponseRedirect
from formtools.wizard.views import SessionWizardView
from .forms import IdForm, BibliographyForm, PDBForm, ProteinForm, ProteinDomainComplexForm, PpiForm

def index(request):
    return render(request, 'index.html')

def about(request):
    return render(request, 'about.html')

def query(request):
    return render(request, 'query.html')

def tutorials(request):
    return render(request, 'tutorials.html')

def adminSession(request):
    return render(request, 'admin-session.html')

def add(request):
    # if this is a POST request we need to process the form data
    if request.method == 'POST':
        # create a form instance and populate it with data from the request:
        form = IdForm(request.POST)
        # check whether it's valid:
        if form.is_valid():
            # process the data in form.cleaned_data as required
            # ...
            # redirect to a new URL:
            return HttpResponseRedirect('/admin-session/add')

    # if a GET (or any other method) we'll create a blank form
    else:
        form = IdForm()

    return render(request, 'add.html', {'ID': form})


FORMS = [("IdForm", ippidb.forms.IdForm),
         ("BibliographyForm", ippidb.forms.BibliographyForm),
         ("PDBForm", ippidb.forms.PDBForm),
         ("ProteinDomainComplexForm", ippidb.forms.ProteinDomainComplexForm),
         ("PpiForm", ippidb.forms.PpiForm)]

TEMPLATES = {"IdForm": "IdForm.html",
             "BibliographyForm": "BibliographyForm.html",
             "PDBForm": "PDBForm.html",
             "ProteinDomainComplexForm": "ProteinDomainComplexForm.html",
             "PpiForm": "PpiForm.html"}

class IppiWizard(SessionWizardView):
    def get_template_names(self):
        return [TEMPLATES[self.steps.current]]
        
    def done(self, form_list, **kwargs):
        return render(self.request, '/admin-session/add.html', {
            'form_data': [form.cleaned_data for form in form_list],
        })

# def add(request):
#     # if this is a POST request we need to process the form data
#     if request.method == 'POST':
#         # create a form instance and populate it with data from the request:
#         form = BibliographyForm(request.POST)
#         # check whether it's valid:
#         if form.is_valid():
#             # process the data in form.cleaned_data as required
#             # ...
#             # redirect to a new URL:
#             return HttpResponseRedirect('/admin-session/add')

#     # if a GET (or any other method) we'll create a blank form
#     else:
#         form = BibliographyForm()

#     return render(request, 'add.html', {'Biblio': form})

